@@ -5,7 +5,8 @@ import redis.asyncio as redis
 import socket
 import logging
 import json
-from typing import Any, Awaitable, Callable
+import warnings
+from typing import Any, Awaitable, Callable, cast
 
 log = logging.getLogger(__name__)
 log.addHandler(logging.NullHandler())
@@ -25,19 +26,25 @@ class UnknownError(RpcException):
 class NotAuthorizedError(RpcException):
     pass
 
+class RpcExchangerRpcHandler2:
+    def __init__(self, exchanger: RpcExchanger,  provider: str) -> None:
+        self._exchanger = exchanger
+        self._provider = provider
+
+    def __getattr__(self, service: str):
+        async def func(**data):
+            result = await self._exchanger.rpc_request(self._provider+"/"+service, data)
+            log.debug(f"{result=}")
+            return result
+            
+        return func
+
 class RpcExchangerRpcHandler:
     def __init__(self, exchanger: RpcExchanger) -> None:
         self._exchanger = exchanger
 
     def __getattr__(self, provider: str):
-        def wrapper(service):
-            async def func(**data):
-                result = await self._exchanger.rpc_request(provider+"/"+service, data)
-                log.debug(f"{result=}")
-                return result
-            return func
-            
-        return type(provider,(),{"__getattr__":lambda self,service:wrapper(service)})()
+        return RpcExchangerRpcHandler2(self._exchanger, provider)
 
 class RpcExchanger:
     """Low-level api which is hard to use"""
@@ -160,8 +167,8 @@ class RpcExchangerClient:
             log.debug(f"{raw_message['data']=} {raw_message['channel']=}")
             try:
                 json_content = json.loads(raw_message["data"].decode())
-                username: str = json_content["username"]
-                msg: str = json_content["msg"]
+                username = json_content["username"]
+                msg = json_content["msg"]
                 chat = int(raw_message["channel"][9:])
                 log.debug(f"{username=} {msg=} {chat=}")
             except Exception as e:
@@ -170,9 +177,14 @@ class RpcExchangerClient:
         return username, msg, chat
 
     async def chat_create(self, name: str) -> int:
+        warnings.warn(DeprecationWarning("chat_create is deprecated, use chat_create2 instead"))
         self.check_authorized()
         return await self._rpc.chat.create(name=name)
 
+    async def chat_create2(self, name: str) -> int:
+        self.check_authorized()
+        return await self._rpc.chat.create_with_user(name=name, user_id=self._uid)
+
     async def chat_get_name(self, id: int) -> str:
         self.check_authorized()
         return await self._rpc.chat.get_name(id=id)
@@ -208,7 +220,7 @@ class RpcExchangerClient:
     async def chat_list_somebody_joined(self) -> list[tuple[int, str]]:
         self.check_authorized()
         result: list[tuple[int, str]] = [
-            tuple(i) for i in await self._rpc.chat.list_somebody_joined(id=self._uid)
+            cast(Any, tuple(i)) for i in await self._rpc.chat.list_somebody_joined(id=self._uid)
         ]
         result_set = {i[0] for i in result}
         async with self._chat_list_lock:
